==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/quicksight/kotlin/outputs/GetDataSetLogicalTableMapSourceJoinInstruction.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.quicksight.kotlin.outputs

import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property leftJoinKeyProperties
 * @property leftOperand
 * @property onClause
 * @property rightJoinKeyProperties
 * @property rightOperand
 * @property type
 */
public data class GetDataSetLogicalTableMapSourceJoinInstruction(
    public val leftJoinKeyProperties:
    List<GetDataSetLogicalTableMapSourceJoinInstructionLeftJoinKeyProperty>,
    public val leftOperand: String,
    public val onClause: String,
    public val rightJoinKeyProperties:
    List<GetDataSetLogicalTableMapSourceJoinInstructionRightJoinKeyProperty>,
    public val rightOperand: String,
    public val type: String,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.quicksight.outputs.GetDataSetLogicalTableMapSourceJoinInstruction):
            GetDataSetLogicalTableMapSourceJoinInstruction =
            GetDataSetLogicalTableMapSourceJoinInstruction(
                leftJoinKeyProperties = javaType.leftJoinKeyProperties().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.quicksight.kotlin.outputs.GetDataSetLogicalTableMapSourceJoinInstructionLeftJoinKeyProperty.Companion.toKotlin(args0)
                    })
                }),
                leftOperand = javaType.leftOperand(),
                onClause = javaType.onClause(),
                rightJoinKeyProperties = javaType.rightJoinKeyProperties().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.quicksight.kotlin.outputs.GetDataSetLogicalTableMapSourceJoinInstructionRightJoinKeyProperty.Companion.toKotlin(args0)
                    })
                }),
                rightOperand = javaType.rightOperand(),
                type = javaType.type(),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/quicksight/kotlin/outputs/GetDataSetLogicalTableMapSourceJoinInstruction.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.quicksight.kotlin.outputs

import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property leftJoinKeyProperties
 * @property leftOperand
 * @property onClause
 * @property rightJoinKeyProperties
 * @property rightOperand
 * @property type
 */
public data class GetDataSetLogicalTableMapSourceJoinInstruction(
    public val leftJoinKeyProperties: List<GetDataSetLogicalTableMapSourceJoinInstructionLeftJoinKeyProperty>,
    public val leftOperand: String,
    public val onClause: String,
    public val rightJoinKeyProperties: List<GetDataSetLogicalTableMapSourceJoinInstructionRightJoinKeyProperty>,
    public val rightOperand: String,
    public val type: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.quicksight.outputs.GetDataSetLogicalTableMapSourceJoinInstruction): GetDataSetLogicalTableMapSourceJoinInstruction =
            GetDataSetLogicalTableMapSourceJoinInstruction(
                leftJoinKeyProperties = javaType.leftJoinKeyProperties().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.quicksight.kotlin.outputs.GetDataSetLogicalTableMapSourceJoinInstructionLeftJoinKeyProperty.Companion.toKotlin(args0)
                    })
                }),
                leftOperand = javaType.leftOperand(),
                onClause = javaType.onClause(),
                rightJoinKeyProperties = javaType.rightJoinKeyProperties().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.quicksight.kotlin.outputs.GetDataSetLogicalTableMapSourceJoinInstructionRightJoinKeyProperty.Companion.toKotlin(args0)
                    })
                }),
                rightOperand = javaType.rightOperand(),
                type = javaType.type(),
            )
    }
}
